@@ -1,39 +1,56 @@
 """Batch processing of the audio files."""
 
-from audiorename.audiofile import do_job_on_audiofile
-from audiorename.audiofile import mb_track_listing
-from phrydy import MediaFile
 import os
-import phrydy
+import typing
+
+from phrydy import MediaFileExtended
+
+from .job import Job
+from .audiofile import do_job_on_audiofile, mb_track_listing
 
 
-class Batch(object):
-    """This class first sorts all files and then walks through all files. At
-    this process it tries to make bundles of files belonging to a album. This
-    bundle of files is temporary stores in the attribute `virtual_album`. This
-    complicated mechanism is needed for the both filters `album_complete` and
+class VirtualAlbum:
+
+    title: str
+    track: int
+    path: str
+
+    def __init__(self, title: str, track: int, path: str) -> None:
+        self.title = title
+        self.track = track
+        self.path = path
+
+
+class Batch:
+    """This class first sorts all files and then walks through all files. In
+    this process it tries to make bundles of files belonging to an album. This
+    bundle of files is temporary stored in the attribute `virtual_album`. This
+    complicated mechanism is needed for the two filters `album_complete` and
     `album_min`.
-
-    :param job: The `job` object.
-    :type job: audiorename.job.Job
     """
 
-    virtual_album = []
+    virtual_album: typing.List[VirtualAlbum] = []
     """Storage of a list of files belonging to an album."""
 
-    current_album_title = ''
+    current_album_title: str = ''
     """Storage for the album title of the current audio file."""
 
-    def __init__(self, job):
-        self.job = job
-        self.bundle_filter = job.filter.album_complete or job.filter.album_min
+    job: Job
 
-    def check_extension(self, path):
+    bundle_filter: bool
+
+    def __init__(self, job: Job):
+
+        self.job = job
+        self.bundle_filter = job.filters.album_complete or \
+            isinstance(job.filters.album_min, int)
+
+    def check_extension(self, path: str) -> bool:
         """Check the extension of the track.
 
         :params str path: The path of the tracks.
         """
-        extension = self.job.filter.extension
+        extension = self.job.filters.extension
         extension = ['.' + e for e in extension]
         if path.lower().endswith(tuple(extension)):
             return True
@@ -44,7 +61,8 @@ class Batch(object):
         """Compare the number of tracks in an album with the minimal track
         threshold.
         """
-        if len(self.virtual_album) > int(self.job.filter.album_min):
+        if isinstance(self.job.filters.album_min, int) and \
+                len(self.virtual_album) > int(self.job.filters.album_min):
             return True
         else:
             return False
@@ -52,9 +70,9 @@ class Batch(object):
     def check_completeness(self):
         """Check if the album is complete"""
         max_track = 0
-        for record in self.virtual_album:
-            if record['track'] > max_track:
-                max_track = record['track']
+        for album in self.virtual_album:
+            if album.track > max_track:
+                max_track = album.track
 
         if len(self.virtual_album) == max_track:
             return True
@@ -65,18 +83,18 @@ class Batch(object):
         """Check an album for quantity and completeness."""
         quantity = True
         completeness = True
-        if self.job.filter.album_min and not self.check_quantity():
+        if self.job.filters.album_min and not self.check_quantity():
             quantity = False
-        if self.job.filter.album_complete and not self.check_completeness():
+        if self.job.filters.album_complete and not self.check_completeness():
             completeness = False
 
         if quantity and completeness:
-            for p in self.virtual_album:
-                do_job_on_audiofile(p['path'], job=self.job)
+            for album in self.virtual_album:
+                do_job_on_audiofile(album.path, job=self.job)
 
         self.virtual_album = []
 
-    def make_bundles(self, path=''):
+    def make_bundles(self, path: str = ''):
         """
         :params str path: The path of the tracks.
         """
@@ -85,25 +103,22 @@ class Batch(object):
             return
 
         try:
-            media = MediaFile(path)
-            record = {}
-            record['title'] = media.album
-            record['track'] = media.track
-            record['path'] = path
+            media = MediaFileExtended(path)
+            album = VirtualAlbum(media.album, media.track, path)
             if not self.current_album_title or \
                     self.current_album_title != media.album:
                 self.current_album_title = media.album
                 self.process_album()
-            self.virtual_album.append(record)
-        except phrydy.mediafile.UnreadableFileError:
+            self.virtual_album.append(album)
+        except Exception:
             pass
 
     def execute(self):
         """Process all files of a given path or process a single file."""
 
         mb_track_listing.counter = 0
-        if os.path.isdir(self.job.source):
-            for path, dirs, files in os.walk(self.job.source):
+        if os.path.isdir(self.job.selection.source):
+            for path, dirs, files in os.walk(self.job.selection.source):
                 dirs.sort()
                 files.sort()
                 for file_name in files:
@@ -119,6 +134,6 @@ class Batch(object):
                 self.make_bundles()
 
         else:
-            p = self.job.source
+            p = self.job.selection.source
             if self.check_extension(p):
                 do_job_on_audiofile(p, job=self.job)
