@@ -15,11 +15,13 @@ if typing.TYPE_CHECKING:
 
 class KeyValue:
 
+    kv: "OrderedDict[str, str]"
+
     def __init__(self, color: bool = False):
         self.color = color
         self.kv = OrderedDict()
 
-    def add(self, key, value) -> None:
+    def add(self, key: str, value: str) -> None:
         self.kv[key] = value
 
     def result(self) -> str:
@@ -32,7 +34,7 @@ class KeyValue:
         return out
 
     def result_one_line(self) -> str:
-        out = []
+        out: typing.List[str] = []
         for key, value in self.kv.items():
             if self.color:
                 key = ansicolor.green(key)
@@ -48,10 +50,14 @@ class Message:
     :type job: audiorename.job.Job
     """
 
-    def __init__(self, job):
-        self.color = job.output.color
-        self.verbose = job.output.verbose
-        self.one_line = job.output.one_line
+    color: bool
+    verbose: bool
+    one_line: bool
+
+    def __init__(self, job: "Job"):
+        self.color = job.cli_output.color
+        self.verbose = job.cli_output.verbose
+        self.one_line = job.cli_output.one_line
         self.max_field = self.max_fields_length()
         self.indent_width = 4
 
@@ -59,7 +65,7 @@ class Message:
     def max_fields_length() -> int:
         return phrydy.doc_generator.get_max_field_length(all_fields)
 
-    def output(self, text='') -> None:
+    def output(self, text: str = '') -> None:
         if self.one_line:
             print(text.strip(), end=' ')
         else:
@@ -68,7 +74,8 @@ class Message:
     def template_indent(self, level: int = 1) -> str:
         return (' ' * self.indent_width) * level
 
-    def template_path(self, audio_file: 'AudioFile'):
+    def template_path(self, audio_file: 'AudioFile') -> str:
+        path: str
         if self.verbose:
             path = audio_file.abspath
         else:
@@ -104,13 +111,13 @@ class Message:
         self.output(self.template_indent(2) + 'to:')
         self.output(self.template_indent(2) + self.template_path(target))
 
-    def best_format(self, best, attr, source: 'Meta',
-                    target: 'Meta') -> None:
+    def best_format(self, best: typing.Literal['target', 'source'], attr: str,
+                    source: 'Meta', target: 'Meta') -> None:
         source_attr = getattr(source, attr)
         target_attr = getattr(target, attr)
 
         if source_attr == target_attr and best == 'target':
-            self.output('Best format: Source and target have the some formats,'
+            self.output('Best format: Source and target have the same formats,'
                         ' use target.')
         else:
             self.output(
@@ -119,13 +126,13 @@ class Message:
                 'target: ' + str(target_attr) + ')'
             )
 
-    def diff(self, key, value1, value2):
+    def diff(self, key: str, value1: str, value2: str):
         key_width = self.max_field + 2
         value2_indent = self.indent_width + key_width
         key += ':'
         key = key.ljust(self.max_field + 2)
 
-        def quote(value):
+        def quote(value: typing.Any):
             return '“' + str(value) + '”'
 
         value1 = quote(value1)
@@ -155,29 +162,29 @@ class Message:
 
 
 def job_info(job: 'Job') -> None:
-    versions = KeyValue(job.output.color)
+    versions = KeyValue(job.cli_output.color)
     versions.add('audiorename', audiorename.__version__)
     versions.add('phrydy', phrydy.__version__)
     versions.add('tmep', tmep.__version__)
 
-    info = KeyValue(job.output.color)
+    info = KeyValue(job.cli_output.color)
     info.add('Versions', versions.result_one_line())
-    info.add('Action', job.rename.move)
-    info.add('Source', job.source)
-    info.add('Target', job.target)
-    if job.rename.cleanup == 'backup':
+    info.add('Action', job.rename.move_action)
+    info.add('Source', job.selection.source)
+    info.add('Target', job.selection.target)
+    if job.rename.cleaning_action == 'backup':
         info.add('Backup folder', job.rename.backup_folder)
 
-    if job.output.verbose:
-        info.add('Default', job.format.default)
-        info.add('Compilation', job.format.compilation)
-        info.add('Soundtrack', job.format.soundtrack)
+    if job.cli_output.verbose:
+        info.add('Default', job.path_templates.default)
+        info.add('Compilation', job.path_templates.compilation)
+        info.add('Soundtrack', job.path_templates.soundtrack)
 
     print(info.result())
 
 
 def stats(job: 'Job') -> None:
-    kv = KeyValue(job.output.color)
+    kv = KeyValue(job.cli_output.color)
 
     kv.add('Execution time', job.stats.timer.result())
     kv.add('Counter', job.stats.counter.result())
